#!/usr/bin/env python
# encoding: utf-8

"""
.. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
"""

from __future__ import print_function, unicode_literals

import pytest
from allpairspy import AllPairs


def function_to_be_tested(brand, operating_system, minute):
    # do something

    return True


class TestParameterized(object):
    @pytest.mark.parametrize(
        ["brand", "operating_system", "minute"],
        [
            value_list
            for value_list in AllPairs(
                [["Brand X", "Brand Y"], ["98", "NT", "2000", "XP"], [10, 15, 30, 60]]
            )
        ],
    )
    def test(self, brand, operating_system, minute):
        assert function_to_be_tested(brand, operating_system, minute)



#!/usr/bin/env python
# encoding: utf-8

from __future__ import print_function

from collections import OrderedDict

from allpairspy import AllPairs


parameters = OrderedDict(
    {"brand": ["Brand X", "Brand Y"], "os": ["98", "NT", "2000", "XP"], "minute": [15, 30, 60]}
)

print("PAIRWISE:")
for i, pairs in enumerate(AllPairs(parameters)):
    print("{:2d}: {}".format(i, pairs))



#!/usr/bin/env python
# encoding: utf-8

"""
Another demo of filtering capabilities.
Demonstrates how to use named parameters
"""

from __future__ import print_function

from allpairspy import AllPairs


def is_valid_combination(values, names):

    dictionary = dict(zip(names, values))

    """
    Should return True if combination is valid and False otherwise.

    Dictionary that is passed here can be incomplete.
    To prevent search for unnecessary items filtering function
    is executed with found subset of data to validate it.
    """

    rules = [
        # Brand Y does not support Windows 98
        # Brand X does not work with XP
        # Contractors are billed in 30 min increments
        lambda d: "98" == d["os"] and "Brand Y" == d["brand"],
        lambda d: "XP" == d["os"] and "Brand X" == d["brand"],
        lambda d: "Contr." == d["employee"] and d["increment"] < 30,
    ]

    for rule in rules:
        try:
            if rule(dictionary):
                return False
        except KeyError:
            pass

    return True


# sample parameters are is taken from
# http://www.stsc.hill.af.mil/consulting/sw_testing/improvement/cst.html
parameters = [
    ("brand", ["Brand X", "Brand Y"]),
    ("os", ["98", "NT", "2000", "XP"]),
    ("network", ["Internal", "Modem"]),
    ("employee", ["Salaried", "Hourly", "Part-Time", "Contr."]),
    ("increment", [6, 10, 15, 30, 60]),
]

pairwise = AllPairs(
    [x[1] for x in parameters],
    filter_func=lambda values: is_valid_combination(values, [x[0] for x in parameters]),
)

print("PAIRWISE:")
for i, pairs in enumerate(pairwise):
    print("{:2d}: {}".format(i, pairs))



#!/usr/bin/env python
# encoding: utf-8

"""
Demo of the basic functionality - just getting pairwise/n-wise combinations
"""

from __future__ import print_function

from allpairspy import AllPairs


parameters = [
    ["Brand X", "Brand Y"],
    ["98", "NT", "2000", "XP"],
    ["Internal", "Modem"],
    ["Salaried", "Hourly", "Part-Time", "Contr."],
    [6, 10, 15, 30, 60],
]
# sample parameters are is taken from
# http://www.stsc.hill.af.mil/consulting/sw_testing/improvement/cst.html

print("PAIRWISE:")
for i, pairs in enumerate(AllPairs(parameters)):
    print("{:2d}: {}".format(i, pairs))



#!/usr/bin/env python
# encoding: utf-8

from __future__ import print_function

from allpairspy import AllPairs


"""
Provided to make it easier to compare efficiency with other tools
as per http://pairwise.org/tools.asp

Current iuput is:

3^4: produces 9 rows
3^13: produces 17 rows
4^15 * 3^17 * 2^29: produces 37 rows
4^1 * 3^39 * 2^35: produces 27 rows
3^100: produces 29 rows
10^20: produces 219 rows
10^10: produces 172 rows
"""


def get_arrays(dimensions):
    opts = []

    for d in dimensions:
        r = []
        for _i in range(d[1]):
            r.append(range(d[0]))
        opts += r

    return opts


def print_result(dimensions):
    header_list = []
    for d in dimensions:
        header_list.append("%i^%i" % d)

    pairwise = AllPairs(get_arrays(dimensions))
    n = len(list(pairwise))

    print("{:s}: produces {:d} rows".format(" * ".join(header_list), n))


print_result(((3, 4),))
print_result(((3, 13),))
print_result(((4, 15), (3, 17), (2, 29)))
print_result(((4, 1), (3, 39), (2, 35)))
print_result(((3, 100),))
print_result(((10, 20),))
print_result(((10, 10),))



#!/usr/bin/env python
# encoding: utf-8

"""
Demo of filtering capabilities
"""

from __future__ import print_function

from allpairspy import AllPairs


def is_valid_combination(row):
    """
    This is a filtering function. Filtering functions should return True
    if combination is valid and False otherwise.

    Test row that is passed here can be incomplete.
    To prevent search for unnecessary items filtering function
    is executed with found subset of data to validate it.
    """

    n = len(row)

    if n > 1:
        # Brand Y does not support Windows 98
        if "98" == row[1] and "Brand Y" == row[0]:
            return False

        # Brand X does not work with XP
        if "XP" == row[1] and "Brand X" == row[0]:
            return False

    if n > 4:
        # Contractors are billed in 30 min increments
        if "Contr." == row[3] and row[4] < 30:
            return False

    return True


# sample parameters are is taken from
# http://www.stsc.hill.af.mil/consulting/sw_testing/improvement/cst.html
parameters = [
    ["Brand X", "Brand Y"],
    ["98", "NT", "2000", "XP"],
    ["Internal", "Modem"],
    ["Salaried", "Hourly", "Part-Time", "Contr."],
    [6, 10, 15, 30, 60],
]

print("PAIRWISE:")
for i, pairs in enumerate(AllPairs(parameters, filter_func=is_valid_combination)):
    print("{:2d}: {}".format(i, pairs))
